#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.2.0.0
visibility:           public
id:                   hls-graph-2.2.0.0-Fh9UwprOg1BEeLIEJVDqjC
key:                  hls-graph-2.2.0.0-Fh9UwprOg1BEeLIEJVDqjC
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  609d374e95ace4608d93b4f4494ab20c
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-graph-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-graph-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-graph-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.2.0.0-Fh9UwprOg1BEeLIEJVDqjC
depends:
    aeson-2.2.1.0-BfV39Vpjeh9G4TP9CsFVxm
    async-2.2.5-FIWsXw8tceP2d6lj6DHM5i base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-HTBQCN3DO2zH7sDTaOIuTE filepath-1.4.300.1
    focus-1.0.3.2-IsIaN5aNdguL2cZ9Zw7jsE
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    js-dgtable-0.5.2-JIjvuPD3we7ByE7r2A7oMM
    js-flot-0.8.3-CSwWF2xMOrpIfADJpYok8C
    js-jquery-3.7.1-5Cf8MSLqZDkBCRM4c9E3AY
    list-t-1.0.5.7-CE4wI7jXQwQCBAxJx7lhjJ stm-2.5.1.0
    stm-containers-1.2.1.1-DhfuBKiaVAk6SRinVYOgAy text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-5TDFrh4ofEEIRD14KRsITD
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

